@@ -1,4 +1,4 @@
-use std::marker::PhantomData;
+use core::marker::PhantomData;
 use vector::Vector3;
 
 
@@ -8,10 +8,10 @@ use vector::Vector3;
 #[derive(Clone, Copy, Debug, Hash, PartialEq, PartialOrd, Eq, Ord)]
 #[repr(C)]
 pub struct Quaternion<T> {
-    /// Scalar part of a quaternion.
-    pub s: T,
     /// Vector part of a quaternion.
     pub v: Vector3<T>,
+    /// Scalar part of a quaternion.
+    pub s: T,
 }
 
 impl<T> From<[T; 4]> for Quaternion<T> {
@@ -30,7 +30,7 @@ impl<T> Into<[T; 4]> for Quaternion<T> {
 }
 
 impl<T> AsRef<[T; 4]> for Quaternion<T> {
-    fn as_ref(&self) -> &[T; 4] { unsafe { ::std::mem::transmute(self) } }
+    fn as_ref(&self) -> &[T; 4] { unsafe { ::core::mem::transmute(self) } }
 }
 
 
